menu
merry package
documentation
bindings.dart
bindings.dart
dark_mode
light_mode
bindings
library
Constants
blobsPath
→ const
String
packageUri
→ const
String
supported
→ const
Map
<
Abi
,
String
>
Supported operating systems with architectures mapped to blob file extensions.
Functions
getBlobFilename
(
)
→
String
Gets the file name of blob files based on platform
runScript
(
String
script
)
→
Future
<
int
>
Run a given input string in console in native code via dart ffi
merry package
documentation
bindings.dart
merry
package
Libraries
bindings
commands
error
merry
utils
version
bindings library