MerryError class

A custom error type used to catch custom errors with the type ErrorCode.

Inheritance

Constructors

MerryError({required ErrorCode type, Map<String, dynamic> body = const {}})
Constructs a constant MerryError instance.

Properties

body → Map<String, dynamic>
Body message of the error.
final
hashCode → int
The hash code for this object.
no setterinherited
props → List<Object>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
The stack trace at the point where this error was first thrown.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type → ErrorCode
Type of error.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited