Definition class

A typical script definition.

description - is a short descriptive message about the script which will be shown when you use merry ls -d.

scripts - is a list of commands/scripts to execute.

execution - is once to stop after the first failed script, or multiple to run every script.

workdir - optional working directory to run the scripts in.

Constructors

Definition({String? description, required List<String> scripts, String execution = 'multiple', String? workdir})
Constructs a constant Definition instance.
const
Definition.from(dynamic input)
Creates a Definition instance from a dynamic input. The input can be a Map, List or String.
factory

Properties

description → String?
Description message.
final
execution → String
Execution mode for the scripts.
final
hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scripts → List<String>
Scripts contained in the definition.
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
workdir → String?
Optional working directory for script execution.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited