Info class

Package information which includes package name & version with both being String.

Constructors

Info({String? name, String? version})
Constructs a constant Info instance.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name of the package.
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
version → String?
The version of the package.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.

Operators

operator ==(Object other) → bool
The equality operator.
inherited