Reference class

A helper class to represent a reference to a script.

Constructors

Reference({required String script, required List<String> extra})
Constructs a constant Reference instance.
const
Reference.from(String input)
Creates a Reference instance from a String input. The input string must start with a single character as specified via referencePrefix.
factory

Properties

extra → List<String>
The extra arguments to pass down to the script.
final
hashCode → int
The hash code for this object.
no setterinherited
props → List<Object>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
script → String
The script referenced to run.
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited