lookup method
Searches for a given path in the scripts map.
Implementation
dynamic lookup(String path) {
return _searchResults[path] ??= scripts.lookup(path);
}
Searches for a given path in the scripts map.
dynamic lookup(String path) {
return _searchResults[path] ??= scripts.lookup(path);
}