commands library

Classes

ListCommand
The merry ls command which will print a recursive tree representation of all the available scripts within the current config.
RunCommmand
The merry run command which parses the arguments and execute the scripts in the executor using ffi.
SourceCommand
The merry source command which prints out the current config file location.
UpgradeCommand
The merry upgrade command which will attempt to run the pub command to upgrade the merry package itself.