Pubspec class
A singleton class that reads and caches the content of
pubspec.yaml in current directory and provides utilities
for .
Properties
Methods
-
getContent(
) → Future< JsonMap> -
Loads the content of
pubspec.yamlin current directory, this methods must be called before any other method. -
getInfo(
) → Future< Info> -
Returns basic information about the package
defined in
pubspec.yaml. -
getScripts(
) → Future< JsonMap> -
Returns a map of scripts defined in
pubspec.yamlor the scripts from the file path defined inpubspec.yaml. -
getSource(
) → Future< String> -
Returns the file path where the scripts are defined
which can be either
pubspec.yamlor a file path defined inpubspec.yaml. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited