ScriptsRegistry class
A class that holds scripts and provides utilities to work with them.
Constructors
- ScriptsRegistry(JsonMap scriptsMap)
- Constructs a ScriptsRegistry from a JsonMap.
Properties
Methods
-
getAliasMap(
) → Map< String, String> - Returns the alias map, building it lazily on first call.
-
getDefinition(
String scriptString) → Definition - Get a serialized Definition for a script string if it exists. This function will throw errors if the script is not defined or if the script is not valid.
-
getPaths(
) → List< String> - Returns all valid paths to access values from the scripts map.
-
getReference(
String scriptString) → Reference - Compute Reference parts from a script string.
-
getVariables(
) → Map< String, String> - Returns the collected variable map, building it lazily on first call.
-
lookup(
String path) → dynamic - Searches for a given path in the scripts map.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
runScript(
String script, {String extra = ''}) → Future< int> - Runs a script from the scripts map if it exists.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited